==> oddmuse-1.477.tar.gz: oddmuse-1.477/spanish-utf8.pl <==
# UTF-8 encoded Spanish language file for use with Oddmuse
#
# Copyright (c) 2003  Unknown
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt.
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This translation was last checked for Oddmuse version 1.195.
#
%Translate = split('\n',<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Consulta no permitida: el usuario, ip o sub-red ha sido bloqueado.
Could not create %s
No ha sido posible crear %s
Invalid UserName %s: not saved.
UserName %s inválido: no ha sido guardado.
UserName must be 50 characters or less: not saved
UserName debe tener un tamaño de 50 caracteres o menos: no ha sido guardado.
XML::RSS is not available on this system.

diff

history
historial
%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

 . . . . 

Click to edit this page

Invalid action parameter %s
Parámetro de acción %s inválido
Invalid URL.
URL inválida.
Page name is missing

Page name is too long: %s
El nombre de la página es demasiado largo: %s
Invalid Page %s
Página %s Inválida
Invalid Page %s (must not end with .db)
Página %s Inválida (no debe terminar con la extensión .db)
Invalid Page %s (must not end with .lck)
Página %s Inválida (no debe terminar con la extensión .lck)
Page name may not contain space characters: %s
El nombre de la página no puede contener caracteres de espacio: %s
Preview:
Previsualización:
Preview only, not yet saved
Esta es únicamente una vista previa; no ha sido guardada aun.
Please go on to %s.
Por favor proceda a %s.
Could not open %s log file
No ha sido posible abrir el archivo de registro %s
Error was
El error fue
Note: This error is normal if no changes have been made.
Nota: Este error es normal si no se han efectuado modificaciones.
Could not open old %s log file
No ha sido posible abrir el archivo antiguo de registro %s
No updates since %s
No han habido actualizaciones desde %s
Updates since %s
Actualizaciones desde %s
Updates in the last %s days
Actualizaciones en los últimos %s días
Updates in the last %s day
Actualizaciones en el último %s día
for %s only
solo para %s
List latest change per page only

List all changes

List only major changes

Include minor changes

%s days
%s días
List later changes

Filters

Username:

Host:

Language:

Go!
Iniciar
(minor)
(menor)
rollback

new

from %s
desde %s
History of %s
Historial de %s
Compare
Comparar
Revision %s
Revisión %s
by
por
Rolling back changes

Missing target for rollback.

Target for rollback is too far back.

Rollback to %s

%s rolled back

[Home]
[Inicio]
redirected from %s
redireccionado desde %s
Click to search for references to this page

Cookie: 

Warning
Advertencia
Database is stored in temporary directory %s
La base de datos se encuentra almacenada temporalmente en el directorio %s
%s seconds
%s segundos
The same page on other sites:

EditNearLinks

Last edited
Editado por última vez
Edited
Editado
by %s

(diff)

Run maintenance

Unlock site

Lock site

Unlock page

Lock page

Comments on this page
Comentarios de esta página
Edit revision %s of this page
Editar la revisión %s de esta página
Edit text of this page
Editar el contenido de esta página
e

This page is read-only
Esta página se encuentra en modo de sólo-lectura
View other revisions
Ver otras revisiones
View current revision
Ver revisión actual
View all changes

Back to %s

new comment
nuevo comentario
s

Save
Guardar
Preview
Previsualización
Search:
Buscar:
Replace:
Reemplazar:
Validate HTML
Validar HTML
Validate CSS
Validar CSS
Difference (from revision %1 to %2)

revision %s
revisión %s
current revision
revisión actual
Difference (from prior %s revision)
Diferencias (previas a la revisión %s)
major
mayor
minor
menor
No diff available.
No hoy diffs disponibles.
Changed:
Modificado:
Removed:
Eliminado:
Added:
Agregado:
to
a
Revision %s not available
La revisión %s no está disponible.
showing current revision instead
se presenta en su lugar la revisión actual
Showing revision %s
La presente es la revisión %s
Cannot save an nameless page.

Cannot open %s

Cannot write %s

Could not get %s lock

Unlocking
Deshabilitando el bloqueo
This operation may take several seconds...
Esta operación puede tomar varios segundos...
Forced unlock of %s lock.
Se ha forzado la desactivación del bloqueo %s.
No unlock required.
No se requiere una operación de desbloqueo.
%s hours ago
hace %s horas
1 hour ago
hace 1 hora
%s minutes ago
hace %s minutos
1 minute ago
hace 1 minuto
%s seconds ago
hace %s segundos
1 second ago
hace un segundo
just now
hace un instante
Editing Denied
Se ha denegado el permiso de edición
Editing not allowed: user, ip, or network is blocked.
La edición no se es permitida: el usuario, ip o sub-red ha sido bloqueado.
Contact the wiki administrator for more information.
Contacte al administrador del wiki para más información.
The rule %s matched for you.

See %s for more information.

Editing not allowed: %s is read-only.
La edición no se es permitida: %s es de sólo-lectura.
Only administrators can upload files.

Editing revision %s of
Editando la revisión %s de
Editing %s
Editando %s
Editing old revision %s.
Editando la revisión antigua %s.
Saving this page will replace the latest revision with this text.
Al ser guardada esta página, el contenido de la última revisión será reemplazado.
Summary:
Resumen:
This change is a minor edit.
Este cambio es solo una edición menor.
Replace this file with text.

Replace this text with a file.

File to upload: 

Files of type %s are not allowed.

Password
Contraseña
Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Su contraseña es almacenada en una cookie, si su navegador tiene habilitado su uso. Estas cookies pueden perderse si se conecta desde otra máquina, otra cuenta, o usando un software de navegación diferente.
You are currently an administrator on this site.
Actualmente usted es un administrador en este sitio.
You are currently an editor on this site.
Actualmente usted es un editor en este sitio.
You are a normal user on this site.
Usted es un usuario normal en este sitio.
Your password does not match any of the  administrator or editor passwords.
Su contraseña no coincide con ninguna de las contraseñas de administrador o editor.
Password:
Contraseña:
This site does not use admin or editor passwords.
Este sitio no utiliza contraseñas de administrador o editor.
This operation is restricted to site editors only...
Esta operación está restringida para su uso por editores únicamente...
This operation is restricted to administrators only...
Esta operación está restringida para su uso por administradores únicamente...
Rule "%1" matched "%2" on this page.

Index of all pages
Índice de todas las páginas
all pages

permanent anchors

near links

(for %s)

%s pages found.

Replaced: %s
Reemplazado: %s
Search for: %s
Buscar por: %s
View changes for these pages

Search sites on the %s as well

and

or

Fetching results from %s:

Near pages:

last updated
actualizado por última vez
Complete Content
Contenido Completo
The main page is %s.
La página principal es %s.
Editing not allowed for %s.
No se permite la edición para %s.
SampleUndefinedPage
PaginaEjemploSinDefinir
%s cannot be defined.
%s no puede ser definida.
Sample_Undefined_Page
Pagina_Ejemplo_Sin_Definir
[[%s]] cannot be defined.
[[%s]] no puede ser definida.
Only an administrator can create %s.

Transfer Error: %s

Browser reports no file info.

Browser reports no file type.

Edit Denied

The page contains banned text.

This page was changed by somebody else %s.

The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.

Anonymous
Anónimo
Could not get a lock to merge!
¡No pudo obtenerse un bloqueo para incorporar los cambios!
you

ancestor

other

Maintenance on all pages
Mantenimiento en todas las páginas
Maintenance not done.
El mantenimiento no se ha realizado.
(Maintenance can only be done once every 12 hours.)
(El mantenimiento solo puede realizarse cada 12 horas.)
Remove the "maintain" file or wait.
Elimine el archivo "maintain" o espere.
Main lock obtained.
Se obtuvo el bloqueo principal.
Expiring keep files and deleting pages marked for deletion
Expirando los archivos "keep" y eliminando las páginas marcadas para borrado
not deleted: 

deleted
eliminado
Moving part of the %s log file.
Moviendo parte del archivo de registro %s.
Moving %s log entries.
Moviendo %s entradas del registro.
Getting page index file for %s.

Main lock released.
Se ha liberado el bloqueo principal.
Set or Remove global edit lock
Establecer o Remover el bloqueo global de edición
Edit lock created.
Se ha creado un bloqueo de edición.
Edit lock removed.
Se ha eliminado el bloqueo de edición.
Set or Remove page edit lock
Establecer o Remover el bloqueo de edición de una página
Missing page id to lock/unlock...
No se ha encontrado ID de la página a bloquear/desbloquear...
Lock for %s created.
Se ha creado bloqueo para %s.
Lock for %s removed.
Se ha eliminado bloqueo para %s.
Displaying Wiki Version
Versión del Wiki
Inter links:

Near links:

Too many connections by %s
Demasiadas conexiones de %s
Please do not fetch more than %1 pages in %2 seconds.

Check whether the web server can create the directory %s and whether it can create files in it.

Recent Visitors
Visitantes Recientes
Referrers
Orígenes
All Referrers
Todos los orígenes
anchor first defined here: %s

Click to search for references to this permanent anchor

the page %s also exists

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Delete page

Rename this page to:

Cannot highlight the language %s.

Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.

The match parameter is missing.

Page Collection for %s

Previous

Next

Calendar %s

Footnotes:

image: %s

Index

Languages:

Show!

Define

Full Link List
Lista Completa de Enlaces
Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

Orphan List

Trail: 

None

Type

Permalink to "%s"

Portrait

Static Copy

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Failed to remove %s

The translation is up to date.

The translation is outdated.

The page does not exist.

http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate
alternativo
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
buscar
Blog

END_OF_TRANSLATION

==> oddmuse-1.524.tar.gz: oddmuse-1.524/spanish-utf8.pl <==
# UTF-8 encoded Spanish language file for use with Oddmuse
#
# Copyright (c) 2003  Unknown
#
# Permission is granted to copy, distribute and/or modify this
# document under the terms of the GNU Free Documentation License,
# Version 1.2 or any later version published by the Free Software
# Foundation; with no Invariant Sections, no Front-Cover Texts, and no
# Back-Cover Texts.  A copy of the license could be found at:
# http://www.gnu.org/licenses/fdl.txt.
#
# Installation:
# =============
#
# Create a modules subdirectory in your data directory, and put the
# file in there. It will be loaded automatically.
#
# This translation was last checked for Oddmuse version 1.195.
#
$ModulesDescription .= '<p>$Id: spanish-utf8.pl,v 1.1 2005/01/09 01:42:05 as Exp $</p>';
%Translate = split('\n',<<END_OF_TRANSLATION);
Reading not allowed: user, ip, or network is blocked.
Consulta no permitida: el usuario, ip o sub-red ha sido bloqueado.
Could not create %s
No ha sido posible crear %s
Invalid UserName %s: not saved.
UserName %s inválido: no ha sido guardado.
UserName must be 50 characters or less: not saved
UserName debe tener un tamaño de 50 caracteres o menos: no ha sido guardado.
This page contains an uploaded file:

XML::RSS is not available on this system.

diff

history
historial
%s returned no data, or LWP::UserAgent is not available.

RSS parsing failed for %s

No items found in %s.

 . . . . 

Click to edit this page

image

download

Invalid action parameter %s
Parámetro de acción %s inválido
Invalid URL.
URL inválida.
Page name is missing

Page name is too long: %s
El nombre de la página es demasiado largo: %s
Invalid Page %s
Página %s Inválida
Invalid Page %s (must not end with .db)
Página %s Inválida (no debe terminar con la extensión .db)
Invalid Page %s (must not end with .lck)
Página %s Inválida (no debe terminar con la extensión .lck)
Page name may not contain space characters: %s
El nombre de la página no puede contener caracteres de espacio: %s
Preview:
Previsualización:
Preview only, not yet saved
Esta es únicamente una vista previa; no ha sido guardada aun.
Please go on to %s.
Por favor proceda a %s.
Could not open %s log file
No ha sido posible abrir el archivo de registro %s
Error was
El error fue
Note: This error is normal if no changes have been made.
Nota: Este error es normal si no se han efectuado modificaciones.
Could not open old %s log file
No ha sido posible abrir el archivo antiguo de registro %s
No updates since %s
No han habido actualizaciones desde %s
Updates since %s
Actualizaciones desde %s
Updates in the last %s days
Actualizaciones en los últimos %s días
Updates in the last %s day
Actualizaciones en el último %s día
for %s only
solo para %s
List latest change per page only

List all changes

List only major changes

Include minor changes

%s days
%s días
List later changes

Filters

Username:

Host:

Language:

Go!
Iniciar
(minor)
(menor)
rollback

new

from %s
desde %s
History of %s
Historial de %s
Compare
Comparar
Revision %s
Revisión %s
by
por
Rolling back changes

Missing target for rollback.

Target for rollback is too far back.

Rollback to %s

%s rolled back

Index of all pages
Índice de todas las páginas
Wiki Version
Versión del Wiki
Unlock Wiki
Deshabilitando el bloqueo
Recent Visitors
Visitantes Recientes
Password
Contraseña
Run maintenance

Unlock site

Lock site

Unlock %s

Lock %s

Administration

Actions:

Important pages:

To mark a page for deletion, put <strong>%s</strong> on the first line.

[Home]
[Inicio]
redirected from %s
redireccionado desde %s
Click to search for references to this page

Cookie: 

Warning
Advertencia
Database is stored in temporary directory %s
La base de datos se encuentra almacenada temporalmente en el directorio %s
%s seconds
%s segundos
The same page on other sites:

EditNearLinks

Last edited
Editado por última vez
Edited
Editado
by %s

(diff)

Edit revision %s of this page
Editar la revisión %s de esta página
Edit this page
Editar el contenido de esta página
e

This page is read-only
Esta página se encuentra en modo de sólo-lectura
View other revisions
Ver otras revisiones
View current revision
Ver revisión actual
View all changes

new comment
nuevo comentario
Homepage URL:

s

Save
Guardar
Preview
Previsualización
Search:
Buscar:
f

Replace:
Reemplazar:
Validate HTML
Validar HTML
Validate CSS
Validar CSS
Difference (from revision %1 to %2)

revision %s
revisión %s
current revision
revisión actual
Difference (from prior %s revision)
Diferencias (previas a la revisión %s)
major
mayor
minor
menor
No diff available.
No hoy diffs disponibles.
Old revision:

Changed:
Modificado:
Removed:
Eliminado:
Added:
Agregado:
to
a
Revision %s not available
La revisión %s no está disponible.
showing current revision instead
se presenta en su lugar la revisión actual
Showing revision %s
La presente es la revisión %s
Cannot save a nameless page.

Cannot save a page without revision.

Cannot open %s

Cannot write %s

Could not get %s lock

This operation may take several seconds...
Esta operación puede tomar varios segundos...
Forced unlock of %s lock.
Se ha forzado la desactivación del bloqueo %s.
No unlock required.
No se requiere una operación de desbloqueo.
%s hours ago
hace %s horas
1 hour ago
hace 1 hora
%s minutes ago
hace %s minutos
1 minute ago
hace 1 minuto
%s seconds ago
hace %s segundos
1 second ago
hace un segundo
just now
hace un instante
Editing Denied
Se ha denegado el permiso de edición
Editing not allowed: user, ip, or network is blocked.
La edición no se es permitida: el usuario, ip o sub-red ha sido bloqueado.
Contact the wiki administrator for more information.
Contacte al administrador del wiki para más información.
The rule %s matched for you.

See %s for more information.

Editing not allowed: %s is read-only.
La edición no se es permitida: %s es de sólo-lectura.
Only administrators can upload files.

Editing revision %s of
Editando la revisión %s de
Editing %s
Editando %s
Editing old revision %s.
Editando la revisión antigua %s.
Saving this page will replace the latest revision with this text.
Al ser guardada esta página, el contenido de la última revisión será reemplazado.
Summary:
Resumen:
This change is a minor edit.
Este cambio es solo una edición menor.
Replace this file with text.

Replace this text with a file.

File to upload: 

Files of type %s are not allowed.

Your password is saved in a cookie, if you have cookies enabled. Cookies may get lost if you connect from another machine, from another account, or using another software.
Su contraseña es almacenada en una cookie, si su navegador tiene habilitado su uso. Estas cookies pueden perderse si se conecta desde otra máquina, otra cuenta, o usando un software de navegación diferente.
You are currently an administrator on this site.
Actualmente usted es un administrador en este sitio.
You are currently an editor on this site.
Actualmente usted es un editor en este sitio.
You are a normal user on this site.
Usted es un usuario normal en este sitio.
Your password does not match any of the  administrator or editor passwords.
Su contraseña no coincide con ninguna de las contraseñas de administrador o editor.
Password:
Contraseña:
This site does not use admin or editor passwords.
Este sitio no utiliza contraseñas de administrador o editor.
This operation is restricted to site editors only...
Esta operación está restringida para su uso por editores únicamente...
This operation is restricted to administrators only...
Esta operación está restringida para su uso por administradores únicamente...
Rule "%1" matched "%2" on this page.

Without normal pages

Include normal pages

Without permanent anchors

Include permanent anchors

Without near pages

Include near pages

(for %s)

%s pages found.

Replaced: %s
Reemplazado: %s
Search for: %s
Buscar por: %s
View changes for these pages

Search sites on the %s as well

and

or

Fetching results from %s:

Near pages:

last updated
actualizado por última vez
Complete Content
Contenido Completo
The main page is %s.
La página principal es %s.
Comments on this page
Comentarios de esta página
Editing not allowed for %s.
No se permite la edición para %s.
SampleUndefinedPage
PaginaEjemploSinDefinir
%s cannot be defined.
%s no puede ser definida.
Sample_Undefined_Page
Pagina_Ejemplo_Sin_Definir
[[%s]] cannot be defined.
[[%s]] no puede ser definida.
Only an administrator can create %s.

Transfer Error: %s

Browser reports no file info.

Browser reports no file type.

Edit Denied

The page contains banned text.

This page was changed by somebody else %s.

The changes conflict.  Please check the page again.

Please check whether you overwrote those changes.

Anonymous
Anónimo
Cannot delete the index file %s.

Please check the directory permissions.

Your changes were not saved.

Could not get a lock to merge!
¡No pudo obtenerse un bloqueo para incorporar los cambios!
you

ancestor

other

Run Maintenance

Maintenance not done.
El mantenimiento no se ha realizado.
(Maintenance can only be done once every 12 hours.)
(El mantenimiento solo puede realizarse cada 12 horas.)
Remove the "maintain" file or wait.
Elimine el archivo "maintain" o espere.
Main lock obtained.
Se obtuvo el bloqueo principal.
Expiring keep files and deleting pages marked for deletion
Expirando los archivos "keep" y eliminando las páginas marcadas para borrado
not deleted: 

deleted
eliminado
Moving part of the %s log file.
Moviendo parte del archivo de registro %s.
Moving %s log entries.
Moviendo %s entradas del registro.
Getting page index file for %s.

Main lock released.
Se ha liberado el bloqueo principal.
Set or Remove global edit lock
Establecer o Remover el bloqueo global de edición
Edit lock created.
Se ha creado un bloqueo de edición.
Edit lock removed.
Se ha eliminado el bloqueo de edición.
Set or Remove page edit lock
Establecer o Remover el bloqueo de edición de una página
Missing page id to lock/unlock...
No se ha encontrado ID de la página a bloquear/desbloquear...
Lock for %s created.
Se ha creado bloqueo para %s.
Lock for %s removed.
Se ha eliminado bloqueo para %s.
Displaying Wiki Version

Show dependencies

Inter links:

Near links:

Show parsed link data

Too many connections by %s
Demasiadas conexiones de %s
Please do not fetch more than %1 pages in %2 seconds.

Check whether the web server can create the directory %s and whether it can create files in it.

anchor first defined here: %s

Click to search for references to this permanent anchor

the page %s also exists

Deleting %s

Deleted %s

Renaming %1 to %2.

The page %s does not exist

The page %s already exists

Renamed to %s

Renamed from %s

Renamed %1 to %2.

Immediately delete %s

Rename %s to:

Cannot highlight the language %s.

Missing one of cal(1), Date::Calc(3), or Date::Pcalc(3) to produce the calendar.

The match parameter is missing.

Page Collection for %s

Previous

Next

Calendar %s

Comments on 

Comment on 

Compilation for %s

Compilation tag is missing a regular expression.

Despamming pages

Cannot find revision %s.

Revert to revision %1: %2

Marked as %s.

Cannot find unspammed revision.

Footnotes:

Could not find %1.html template in %2

image: %s

Index

Languages:

Show!

Define

Full Link List
Lista Completa de Enlaces
Template without parameters

The template %s is either empty or does not exist.

%s returned no data.

Clearing Cache

Done.

Generating Link Database

The 404 handler extension requires the link data extension (links.pl).

Orphan List

Trail: 

None

Type

Permalink to "%s"

Portrait

You did not answer correctly.

All Referrers
Todos los orígenes
Referrers
Orígenes
Updating %s

Search term missing.

Static Copy

Back to %s

Alternatively, use one of the following templates:

Thread: %s

ID parameter is missing.

Thread %s does not exist.

Page %s does not contain a thread.

Add

URL parameter is missing.

Add to %s thread

Below:

URL:

Name:

Failed to remove %s

Contents

This page is a translation of %s. 

The translation is up to date.

The translation is outdated.

The page does not exist.

http://shop.barnesandnoble.com/bookSearch/isbnInquiry.asp?isbn=%s

http://www.amazon.com/exec/obidos/ISBN=%s

alternate
alternativo
http://www.pricescan.com/books/BookDetail.asp?isbn=%s

search
buscar
Blog

END_OF_TRANSLATION
